@@ -210,6 +210,8 @@ class FindReplaceWidget(QtWidgets.QFrame):
         # init layout
         layout = QtWidgets.QHBoxLayout(self)
         layout.setSpacing(0)
+        margin = 0
+        layout.setContentsMargins(margin, margin, margin, margin)
         self.setLayout(layout)
 
         # Create some widgets first to realize a correct tab order
@@ -516,27 +518,21 @@ class FindReplaceWidget(QtWidgets.QFrame):
 
         # get text to find
         needle = self._findText.text()
+
+        PatternOption = QtCore.QRegularExpression.PatternOption
+        regexFlags = PatternOption.NoPatternOption
+        if not self._caseCheck.isChecked():
+            regexFlags |= PatternOption.CaseInsensitiveOption
+
         if self._regExp.isChecked():
-            # Make needle a QRegExp; speciffy case-sensitivity here since the
-            # FindCaseSensitively flag is ignored when finding using a QRegExp
-            needle = QtCore.QRegExp(
-                needle,
-                QtCore.Qt.CaseSensitive
-                if self._caseCheck.isChecked()
-                else QtCore.Qt.CaseInsensitive,
-            )
+            needle = QtCore.QRegularExpression(needle, regexFlags)
         elif self._wholeWord.isChecked():
             # Use regexp, because the default begaviour does not find
             # whole words correctly, see issue #276
             # it should *not* find this in this_word
-            needle = QtCore.QRegExp(
-                r"\b" + needle + r"\b",
-                QtCore.Qt.CaseSensitive
-                if self._caseCheck.isChecked()
-                else QtCore.Qt.CaseInsensitive,
-            )
+            needle = QtCore.QRegularExpression(r"\b" + needle + r"\b", regexFlags)
 
-        # estblish start position
+        # establish start position
         cursor = editor.textCursor()
         result = editor.document().find(needle, cursor, flags)
 
@@ -650,6 +646,9 @@ class FileTabWidget(CompactTabWidget):
 
     """
 
+    # Signal to indicate that file tabs were added, updated or removed
+    fileTabsChanged = QtCore.Signal()
+
     def __init__(self, parent):
         CompactTabWidget.__init__(self, parent, padding=(2, 1, 0, 4))
 
@@ -839,6 +838,8 @@ class FileTabWidget(CompactTabWidget):
             items[theIndex].editor.destroy()
             gc.collect()
 
+            self.fileTabsChanged.emit()
+
     def addItem(self, item, update=True):
         """addItem(item, update=True)
 
@@ -946,6 +947,8 @@ class FileTabWidget(CompactTabWidget):
             but = tabBar.tabButton(i, QtWidgets.QTabBar.LeftSide)
             but.updateIcon(item.dirty, self._mainFile == item.id, item.pinned, nBlocks)
 
+        self.fileTabsChanged.emit()
+
 
 class EditorTabs(QtWidgets.QWidget):
     """The EditorTabs instance manages the open files and corresponding
@@ -1006,6 +1009,13 @@ class EditorTabs(QtWidgets.QWidget):
         # the widgets are properly sized.
         pyzo.callLater(self.restoreEditorState)
 
+    @property
+    def _fileDialogOptions(self):
+        options = QtWidgets.QFileDialog.Option(0)
+        if not pyzo.config.advanced.useNativeFileDialogs:
+            options |= QtWidgets.QFileDialog.Option.DontUseNativeDialog
+        return options
+
     def addContextMenu(self):
         """Adds a context menu to the tab bar"""
 
@@ -1156,7 +1166,7 @@ class EditorTabs(QtWidgets.QWidget):
         filter += "All (*)"
         if True:
             filenames = QtWidgets.QFileDialog.getOpenFileNames(
-                self, msg, startdir, filter
+                self, msg, startdir, filter, options=self._fileDialogOptions
             )
             if isinstance(filenames, tuple):  # PySide
                 filenames = filenames[0]
@@ -1164,7 +1174,9 @@ class EditorTabs(QtWidgets.QWidget):
             # Example how to preselect files, can be used when the users
             # opens a file in a project to select all files currently not
             # loaded.
-            d = QtWidgets.QFileDialog(self, msg, startdir, filter)
+            d = QtWidgets.QFileDialog(
+                self, msg, startdir, filter, options=self._fileDialogOptions
+            )
             d.setFileMode(d.ExistingFiles)
             d.selectFile('"codeparser.py" "editorStack.py"')
             d.exec_()
@@ -1195,7 +1207,9 @@ class EditorTabs(QtWidgets.QWidget):
 
         # show dialog
         msg = "Select a directory to open"
-        dirname = QtWidgets.QFileDialog.getExistingDirectory(self, msg, startdir)
+        dirname = QtWidgets.QFileDialog.getExistingDirectory(
+            self, msg, startdir, options=self._fileDialogOptions
+        )
 
         # was a dir selected?
         if not dirname:
@@ -1329,7 +1343,9 @@ class EditorTabs(QtWidgets.QWidget):
         filter += "C (*.c *.h *.cpp);;"
         # filter += "Py+Cy+C (*.py *.pyw *.pyi *.pyx *.pxd *.c *.h *.cpp);;"
         filter += "All (*.*)"
-        filename = QtWidgets.QFileDialog.getSaveFileName(self, msg, startdir, filter)
+        filename = QtWidgets.QFileDialog.getSaveFileName(
+            self, msg, startdir, filter, options=self._fileDialogOptions
+        )
         if isinstance(filename, tuple):  # PySide
             filename = filename[0]
 
@@ -1516,6 +1532,7 @@ class EditorTabs(QtWidgets.QWidget):
         pyzo.config.state.find_matchCase = fr._caseCheck.isChecked()
         pyzo.config.state.find_regExp = fr._regExp.isChecked()
         pyzo.config.state.find_wholeWord = fr._wholeWord.isChecked()
+        pyzo.config.state.find_autoHide = fr._autoHide.isChecked()
         pyzo.config.state.find_show = fr.isVisible()
         #
         pyzo.config.state.editorState2 = self._getCurrentOpenFilesAsSsdfList()
@@ -1530,6 +1547,8 @@ class EditorTabs(QtWidgets.QWidget):
                 self.newFile()
         else:
             self.newFile()
+        self._tabs.updateItems()  # without this, a single restored editor will not have
+        # correct PINNED/MAINFILE symbols
 
         # The find/replace state is set in the corresponding class during init
 
